#[non_exhaustive]pub enum ResponseFormat {
Text,
JsonObject,
JsonSchema {
name: String,
schema: Value,
strict: bool,
},
}Expand description
Constrains the output format of a language model response.
Providers that don’t support a given format return
LanguageModelError::Provider.
Provider support
| Format | OpenAI | Anthropic | Ollama |
|---|---|---|---|
Text | All models | All models | All models |
JsonObject | Most models | Not supported | Supported |
JsonSchema | Newer models | Beta (sonnet-4-5+, opus-4-1+) | Supported |
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Text
No constraint — free-form text (default).
JsonObject
Must produce valid JSON (no schema constraint).
OpenAI requires that you also instruct the model to produce JSON in
your system or user messages — setting this alone is not sufficient.
JsonSchema
Must produce JSON conforming to the given schema.